=======
HISTORY
=======

1.3.12 (2015-07-30)
-------------------

- Rerelease due to possible brown bag release.
  [maurits]


1.3.11 (2015-07-29)
-------------------

- deactivate diazo for ``@@tinymce-upload`` view to make
  sure ``uploadOk`` script is called to update the
  content browser panel.
  [fRiSi]

- UI and UX improvements: Do not cover upload button.
  Clickable icons. (fixes #106) [fRiSi]

- Fixed current image scale in image popups
  [huubbouma]


1.3.10 (2015-06-26)
-------------------

- Fix Brazilian Portuguese translations (closes `#99`_).
  [rodfersou]

- Update tinymce to 3.5.11.
  [maethu]


1.3.9 (2015-04-29)
------------------

- Update Brazilian Portuguese translation.
  [erico]


1.3.8 (2014-11-05)
------------------

- Fix i18n of upload error messages.
  [vincentfretin]

- Update Italian, Czech, French translations.

- Update Traditional Chinese translations.
  [marr]


1.3.7 (2014-09-11)
------------------

- Call convertURL when inserting link or image.
  Fixes `#13721`__.
  [maurits]

__ https://dev.plone.org/ticket/13721


1.3.6 (2014-02-19)
------------------

- Reapplied fix for missing popups when zoom is applied in Chrome from pull
  request 29. Credits go to bosim, raekjaer and jaroel for fix
  (close `#13013`__)
  [ichim-david]

__ https://dev.plone.org/ticket/13013

- Pay attention to safe html filter being disabled for tinymce configuration
  [vangheem]

- Fix selector used for finding anchors
  [vangheem]

- Fixed uploading dexterity file via TinyMCE file uploader.
  [kroman0]

- Updated media plugin; added styling to placeholder generated by media
  plugin.
  [tiberiuichim]

- French translations.
  [thomasdesvenain]

- Do not load styles with conditional comments if the user agent doesn't
  contain Trident when computin getStyle, otherwise we load IE styles on non
  IE browsers
  [ichim-david]

- Require ``plone.app.layout==2.3.7`` which includes bodyClass fix.
  [saily]

- Valid HTML 5 attribute ``start`` for ``ol`` no more removed
  (close `#13566`__)
  [keul]

__ https://dev.plone.org/ticket/13566

1.3.5 (2013-08-14)
------------------

- Fixed an issue where the search button wasn't doing anything when livesearch
  is disabled since checkSearch wasn't checking for a click keycode
  [ichim-david]

- Handle brain.Description when it's ``None`` or ``unicode`` because
  decoding None or unicode is not supported.
  [saily]

- Better match the CSS selectors of the rendered HTML, use the same
  body_class in the editor as would be for the default view of the
  context.
  [rpatterson]

- Check for a 'enable_tinymce_livesearch'property in order to override the
  enable_livesearch of site_properties for instances where you want to have
  livesearch enabled on the portal_search and yet you do not want it enabled
  within TinyMCE and the other way around
  [ichim-david]

- Remove unused getImageScales method from the tinymce utility,
  and remove the hard dependency on Archetypes.
  [davisagli]

- Added base-query for json search.  This makes it easier to override
  the search, just as was done for the folderlisting-view.
  [maurits]

- Fixed i18n.
  [jianaijun]

- Fixed language variants Toolbar does not display issue.
  [jianaijun]

- Remove bogus 'class=" "' refs https://dev.plone.org/ticket/13458
  [maartenkling]

- Include the history on http://readthedocs.org/docs/productstinymce/
  [maurits]

- Display workflow state information about content in popups,
  refs https://dev.plone.org/ticket/10858
  [maartenkling]

- Fix popup for existing image in IE8.
  [maurits]

- Updated italian translation
  [keul]

- Make JSON-methods more failsafe
  [tom_gross]

1.3.4 (2013-05-23)
------------------

- Don't rely on jquery-integration.js being active.
  [esteele]

- Add default translation for ``you_are_here`` label. Previously,
  this label was displayed verbatim for English and other languages without
  a translation.
  [davidjb]

- use unicode to return the result of compressor view.
  This fixes UnicodeDecodeError reported on https://dev.plone.org/ticket/13551
  [ericof]

- remove patterns things and only add pat-tinymce class
  [garbas]

- Added some missing Brazilian Portuguese translations
  [ericof]

- Added some missing Dutch translations
  [maartenkling]


1.3.3 (2013-03-26)
------------------

- Added some missing german translations.
  [tschanzt]

- If the fieldTextFormat dropdown does not exist, tinymce failed to start.
  This was obviously a regression, now fixed.
  [izak]


1.3.2 (2013-03-17)
------------------

- use correct base url for temporary portal_factory objects.
  This fixes add image to new item https://dev.plone.org/ticket/13483
  [vangheem]


1.3.1 (2013-03-12)
------------------

- Use jQuery `bind` instead of `on` to support version 1.4.4
  (which is included in Plone 4.2)
  [garbas]

1.3 (2013-03-05)
----------------

- Remove "Fancy grid listing" and "Fancy vertical listing" table
  styles since they don't hardly do anything and no one knows
  what they should actually look like.
  [vangheem]


1.3b10 (2013-03-04)
-------------------

- update danish translations
  [tmog]

- Fix for ajax view on content-anchors for dexterity content types
  [bosim]

- Fixes 'text format' selection. now it activates/deactivates tinymce depending
  on dropdown value (active only when 'text/html' item is selected)
  [garbas]

- Fixed selection of an item in the home folder.
  [vincentpretre]

- Removed use of base_properties from css.dtml files.
  [maurits+thomvl]

- Convert setting to JSON in jsonConfiguration-view not in utility
  [tomgross]

- Allow text other than headings to be used as anchors in the link plugin.

- Removing elements in importhandler is now possible. This closes ticket
  #11481.

- Use consistent method to calculate anchor ids, to allow for markup in
  headers.
  [izak]


1.3b9 (2013-01-17)
------------------

- Added support for images with external URL
  [iElectric]


1.3b8 (2013-01-01)
------------------


- Support passing a maxlength attribute to tinymce_wysiwyg_support.
  [davisagli]

- textarea for tiles is differently configurated then rest of tinymce instances
  [garbas]

- works with or without plone.init.js (from plone.app.toolbar)
  [garbas]

- works when initialized inside bootstrap moda
  [garbas]

- Fixed UnboundLocalError if the context of the editor is neither IFolderish nor Archetypes

- Fixed inclusion of external CSS resources.
  [tom_gross]

- Fixed bundeling of editor with and without JS debug mode
  [tom_gross]

- moved tiny_mce_gzip.js to file rather than having it in a long string
  in the compressor Python module
  [tom_gross]

- Allow arabic numbers in anchor names
  [tom_gross]

1.3b7 (2012-10-29)
------------------

- If the context isn't IFolderish, then the parent really should be,
  since it's got the context in it.
  [lentinj]

- Check if the context is IFolderish even when checkCreationFlag isn't
  available, i.e. when it's a Dexterity content type
  [lentinj]


1.3b6 (2012-10-16)
------------------

- Simplify how TinyMCE's javascript is included. It is now always served
  at the portal root for improved cacheability. This also fixes some
  regressions where TinyMCE was not getting initialized for some fields.
  [davisagli]

- Take context into account so breadcrumbs work e.g. for internal links and
  images [huubbouma]

- Don't break when running portal_setup > import on non-English sites having international
  characters in TinyMCE settings [miohtama]

- Fix the case where on the migrated site customplugins setting can be None, causing
  jsonConfiguration view to raise an exception [miohtama]

- Added support for Archetypes widget specific configuration overrides [miohtama]

1.3b5 (2012-09-28)
------------------

- Determine whether to include WYSIWYG-support based on a check
  on the form widgets, in the case of z3c.form. Previously, we
  would have a special case for a Dexterity-based context, looking
  up form fields based on the FTI. This should be unnecessary
  because the parent (i.e. the form) already has its widgets set
  up and this is a much more robust check.
  [malthe]

- PEP8 and pyflakes cleanup of Upload.py.
  [pjstevns]

- Prevent acquisition in setDescription.
  [pjstevns]

- Fix accidental reset of variable in Upload.py.
  [pjstevns]


1.3b4 (2012-08-31)
------------------

- Hide upgrade steps from @@plone-addsite view.
  [esteele]


1.3b3 (2012-08-30)
------------------

- Link by UID by default
  [jaroel]

- Add dependency on plone.caching
  [iElectric]

- Fixed UID linked images after returning from fullscreen in Chrome
  [tom_gross]

1.3b2 (2012-08-18)
------------------

- Cache TinyMCE with plone.caching
  [tom_gross]

- Fixed two undefined names in Upload.py.  Added dependency on
  zope.app.content.
  [maurits]

- Fixed viewlet error, where DX add view is not (yet) available
  [tom_gross]

- Merge modified plonebrowser UI from hexagonit fork
  [iElectric, vsomogyi]

- Move history and todo to the main package directory and copy/merge etherpad
  changes and history into the package so have have a single point of reference
  for work left/done
  [iElectric, fredvd]

- Allow independent configurations for different richtext fields (Archetypes
  and Dexterity)
  [tom_gross]

- fix editor styles formatting
  [mitchellrj]

- added zcml condition to check if plone.dexterity is installed
  before to register dexterity releated adapters
  [gborelli]

- Add plone.namedfile as dependency
  [iElectric]

- Support using lxml instead of elementtree to find anchors.
  [davisagli]

- Fix original scale (dexterity-based images need 'my_image/@@images/image'
  instead of just 'my_image')
  [pbauer]

- Allow upload of dexterity based images. This is aimed at
  plone.app.contentypes but should work with all dexterity bases-images.
  [pbauer]

- Set visual editor writing direction based on current language, not site
  preference. This closes ticket #10039.
  [iElectric]

- Use getToolByName instead of getUtility for portal_tinymce.
  Seems like getUtility will strip request object from context
  when doing acqusition chain.
  [iElectric]

- Images now have title and alt attributes when rendered. This closes ticket
  #12322
  [iElectric]

- Added "Edit with visual editor" button
  [iElectric]

- Migrated documentation to Sphinx
  [iElectric]

- Adding field to configure formats.

  This option enables you to override and add custom formats. A format
  is for example the style that get applied when you press the bold
  button inside the editor. TinyMCE is equipped with a text formatter
  engine that enables you to specify exacly what it should produce
  when the user clicks the bold button.

  See http://www.tinymce.com/wiki.php/Configuration:formats.
  [malthe]

- Initial Slovenian translation
  [zupo]

- Merge with 3.4.7 TinyMCE upstream release
  [iElectric]

- Remove URI encoding when POSTing
  [iElectric]

- Fix TinyMCE for static portlets
  [iElectric]

- Fix external toolbar functionality from TinyMCE
  [iElectric]

- Fixed issue where custom theme font breaks TinyMCE dialog layout
  due to enlarged <h2> size [miohtama]

1.3-beta1 (2011-10-24)
----------------------

- ploneimage and plonelink plugins have been merged into plonebrowser
  [iElectric]

- dexterity: portal_transforms transform uids to normal links when page is
  rendered -

- Removed KSS
  [tom_gross]

- Reintroduce Plone 3 support
  [tom_gross]

- Use resolveuid as default
  [iElectric]

- Start of using jquery in some of the plugins.
  [iElectric]

- Introduction of shortcuts in browser select image/links
  [iElectric]

- tinymce files are now pulled from upstream git repository
  [iElectric]

- Upgrade tinymce to 3.4.7
  [iElectric]

- Redesign of Image/Link browser, rewrite of javascript to use jquery. Add thumbnails to browser.
  [iElectric, zupo]

- Use TinyMCE compressor to provide editor and plugins
  [tom_gross]

- Fixed http://dev.plone.org/plone/ticket/11681
  [tom_gross]

- Determine mimetype correctly for plone.app.textfield RichText widgets with
  ignoreContext = True (such as on add forms).
  (Requires plone.app.textfield >= 1.1.1)
  [davisagli]

- Removed comma at the end of a dict in tiny_mce_init.js. This fixes javascript
  error on IE7. This was broken in 1.2.10.
  [vincentfretin]


1.2.10 (unreleased)
-------------------

- Fixed AttributeError: 'ATDocumentFieldsView' object has no attribute
  'absolute_url' when using inline editing.  Inline editing then still
  does not work though (checked on Plone 4.2 dev).

- Fixed a few test failures in combination with five.pt.
  [maurits]

- Do not fail with an AttributeError when the member has no
  wysiwyg_editor property.
  Fixes http://dev.plone.org/ticket/12406
  [maurits]

- Initialize TinyMCE with "media_strict: false" to allow embed tags if
  they are removed from the list of nasty tags.
  Fixes https://dev.plone.org/ticket/10681
  [rochecompaan]


1.2.9 (2011-11-24)
------------------

- Display error message when uploading a file with a name consisting
  only of spaces.
  Fixes http://dev.plone.org/plone/ticket/10394
  [maurits]

- Fixed content_css when the Plone Site id is 'plone'.  This is used
  to display the text during editing in the same layout as it appears
  when viewing.
  Fixes http://dev.plone.org/plone/ticket/11430
  [maurits]

- Include Products.CMFCore's permissions.zcml to ensure Plone 4.1 compatibility.
  [thomasdesvenain]

- Use aq_parent instead of getParentNode for Zope trunk compatibility.
  [elro]

- Search does not work with Virtual Hosting (close #10308)
  [keul] [mamico]

1.2.8 (2011-09-19)
------------------

- Support RichTextValues from plone.app.textfield when determining the mimetype
  of the field being edited.
  [davisagli]

- When user tries to upload an image,
  if image type in content types registry is not allowed in current folder,
  TinyMCE tries to add an image of an other content type
  selected as an image type in TinyMCE settings.
  [thomasdesvenain]

1.2.7 (2011-07-05)
------------------

- Do not give a TypeError 'Could not adapt' when trying to adapt a
  context that is not adaptable to IJSONFolderListing and friends.
  Instead return nothing in the ajax call.
  [maurits]

- pep8
  [iElectric]

- Ported tests from doctests to unittests
  [iElectric]

- Add hook to JSONDetails to allow subclasses to supplement or override the results
  [anthonygerrard]

1.2.6 (2011-05-12)
------------------
- Changed the color of the background on the external editor to light gray to make the buttons more visible.
  [davidjonas]


1.2.5 (2011-05-12)
------------------

- Add a CSS class to the `Edit without visual editor` note.
  [hannosch]

- Avoid determining content type as text/plain on Dexterity add views.
  [davisagli]

- In the link "Edit without visual editor", append existing url-parameters.
  Fixes https://dev.plone.org/plone/ticket/11632
  [WouterVH]


1.2.4 (2011-03-22)
------------------

- Use uuidFor(obj) from plone.outputfilters instead of obj.UID() for
  plone.uuid compatibility.
  [elro]

- Internationalization fixes.
  [thomasdesvenain]

- Allows to use tinymce wysiwyg support outside of an Archetypes context.
  (Checks 'force_wysiwyg' variable value to check if wysiwyg support is enabled.)
  [thomasdesvenain]

- Don't acquire when determining the mimetype of the field being edited.
  [davisagli]

- Fixed bug when rendering for anonymous users.
  [elro]

- Remove isTinyMCEEnabled in kssregistry. Refs #11248
  [jaroel]

- Fixed #11597 TinyMCE Right Pane Depends on Center Pane.
  [Brainix]


1.2.3 (2011-02-24)
------------------

- Suppress the WYSIWYG editor for fields whose text format is not HTML, and
  provide a "Edit without visual editor" link like kupu did so that the format
  can be switched from HTML to something else.
  [davisagli]

- Fix wysiwyg_support to correctly respect a user's preference to use no
  wysiwyg editor.
  [davisagli]

- Correctly load image dialog for existing images using the @@images view for
  image scales.
  [davisagli]

- Updated Norwegian translations.
  [mj]

1.2.2 (2011-02-10)
------------------

- Use @@images view for image scales.
  [elro]

- Get anchor names from listAnchorNames method of @@content_anchors.
  [elro]

- Tweak ploneimage.js to use post data for setDescription for compatibility
  with latest zopes. (This makes the image dialogue incompatible with IE6.)
  [elro]

- Fix quoting of description ploneimage.js
  [elro]

- Make setDescription convert to unicode.
  [elro]

1.2.1 (2011-02-10)
------------------

- Be explicit about catching exceptions. Bare excepts are asking for trouble
  in Zopeland folks.
  [elro]

- Do not crash when getting a configuration with styles that have an
  empty line at the end.
  [maurits]

- Handle Missing.Value for uid in JSONFolderListing.
  [elro]

- Set text/css content type on tinymce-getstyle.
  [elro]

- Add option 'auto' for directivity. The directivity will be set depending
  on the content or the portals default language.
  Fixes http://dev.plone.org/plone/ticket/10039
  [csenger]

- Make the spellchecker to be used configurable via the control panel utility.
  [jcbrand]

- Added the 'After the deadline' spelling and grammar checker plugin.
  [jcbrand]

1.2.0 (2011-01-04)
------------------

- Always use an image's description as its caption, and make the image dialog
  edit the description field instead of the image's alt text. This provides
  parity with how captions were handled by kupu, and avoids misusing the alt
  text.
  [davisagli]

- When editing an image, correctly highlight it in the image dialog even if
  the link-by-uid setting changed since the image was added. This fixes
  http://dev.plone.org/plone/ticket/10970.
  [davisagli]

- Remove the resolveuid Python script; a browser view with the same name in
  plone.outputfilters is now used instead to resolve UUIDs.
  [davisagli]

- Deprecated various helpers in plone.outputfilters.setuphandlers since they
  now duplicate functions in plone.outputfilters.
  [davisagli]

- Use the resolveuid and captioning transforms from plone.outputfilters
  instead of implementing our own. See http://dev.plone.org/plone/ticket/9938
  for details.
  [davisagli]

1.1.7 (2011-02-10)
------------------

- Make sure that tinymce-jsonconfiguration is traversed as a view in
  tinymce_wysiwyg_support.pt.
  [davisagli]

1.1.6 (2011-01-04)
------------------

- Fix capitalization of the title of the content_css setting. This fixes
  http://dev.plone.org/plone/ticket/10792.
  [dariog, davisagli]

- Protect the control panel using the "Plone Site Setup: TinyMCE" permission,
  instead of the generic "Manage portal". Also, add the Site Administrator
  role to the default roles for this permission, for forward compatibility with
  Plone 4.1.
  [davisagli]

- Add tinymce-jsonconfiguration browser view and use it in the template
  tinymce_wysiwyg_support.pt. Make it easier to customize
  [toutpt]

1.1.5 (2010-11-14)
------------------

- Updated translations (de)
  [Plone translators]

- Make sure we fail gracefully on unfound UIDs when kupu isn't installed.
  [jbaldivieso]

- Removed profiles/uninstall/portal-tinymce.txt as it needlessly
  triggered a call to add_editor right before calling remove_editor.
  [maurits]

1.1.4 (2010-09-28)
------------------

- Updated translations (zh_TW)
  [Plone translators]

1.1.3 (2010-09-16)
------------------

- Updated translations
  [Plone translators]

- Fix lang and init files not loaded when @ in URL
  [jaroel]

1.1.2 (2010-08-05)
------------------

- Fix regression that broke the resolveuid transform if an `alt` attribute
  was provided.
  [davisagli]

1.1.1 (2010-07-25)
------------------

- Add styling to set the fontsize for Plone3 only. This fixes
  http://dev.plone.org/plone/ticket/10683
  [jaroel]

- Assume TinyMCE as the site's default editor if none is set. This closes
  http://dev.plone.org/plone/ticket/10810.
  [jaroel]

- Use urllib.unquote. This closes http://dev.plone.org/plone/ticket/10807.
  [jaroel]

- Apply a workaround to fix the "Paste Text" dialog.
  [davisagli]

1.1 (2010-07-23)
----------------

- If we set a description within tinymce (which is written to the `alt`
  attribute of the image tag then) we want to keep that one as image caption.
  Added check for `alt` attribute in Products.TinyMCE.transforms.parser.
  [hpeteragitator]

- In Products.TinyMCE.transforms.parser, added `full_path = unquote(full_path)`
  to remove any encoded characters from path before doing the catalog query.
  [hpeteragitator]

- Make the wysiwyg_support macros fall back to the default editor if the
  current user has an editor preference that is no longer installed.
  Fixes http://dev.plone.org/plone/ticket/10753
  [davisagli]

- Fixed `#undefined` in style selection for lists. This closes
  http://dev.plone.org/plone/ticket/10684.
  [hannosch]

- Hide the non-functioning advanced table options. This closes
  http://dev.plone.org/plone/ticket/10535.
  [hannosch]

- Enhance Rob's default table style fix by specifying a proper title and
  avoiding the duplication of the default `plain` entry. This refs
  http://dev.plone.org/plone/ticket/10534.
  [hannosch]

- Removed redundant `Image list` from image dialog. This closes
  http://dev.plone.org/plone/ticket/10342.
  [hannosch]

- Adopted TinyMCE's build process to generate a minified version of the main
  JavaScript file.
  [hannosch]

- Changed css registration, so it doesn't cause an extra CSS download, but is
  merged with the other anonymous CSS files.
  [hannosch]

- Set 'plain' as default table class.
  [robgietema]

- Fixed issue with style dropdown in IE.
  [robgietema]

- Fixed issue with inline editing of collections.
  [robgietema]

- Set ordering of link and image dialogs to getObjPositionInParent.
  [robgietema]

- Refactor resolveuid to use portal_catalog and not waking up object.
  [toutpt]

- Add tinymce-plone3.css. fix #10683: TinyMCE / Plone3.3 display text too big
  [toutpt]

1.1rc13 (2010-07-02)
--------------------

- Updated to upstream translations.
  table_dlg_scope_col and table_dlg_scope_row msgids doesn't exist
  in tinymce domain, replaced by table_col and table_row in
  skins/tinymce/plugins/table/cell.htm.pt
  [vincentfretin]

- Internationalized list/definition style names
  [thomasdesvenain]

- French translations
  [thomasdesvenain]

- Fix icons in link dialog listing. This closes
  http://dev.plone.org/plone/ticket/10665
  [davisagli]

- Fix icons in image dialog listings. This closes
  http://dev.plone.org/plone/ticket/10538
  [davisagli]

- Reset font size for tables in content.css. This fixes
  http://dev.plone.org/plone/ticket/10536
  [davisagli]

- Apply block format changes even when multiple blocks are selected.
  Fixes http://dev.plone.org/plone/ticket/10145
  [davisagli]

- Look up scale sizes for image types using the field called 'image',
  not the primary field. (They are not necessarily the same.) Fixes
  http://dev.plone.org/plone/ticket/10227
  [davisagli]

- Fix issue when handling images with apostrophes in the title. Fixes
  http://dev.plone.org/plone/ticket/10500
  [davisagli]

- Don't live search in the image and link popups until the search text is at
  least 3 characters long. Fixes http://dev.plone.org/plone/ticket/10458.
  [davisagli]

- Get the portal_url and navigation_root_url in a more sane fashion.
  Fixes http://dev.plone.org/plone/ticket/10423.
  [davisagli]

- Make sure paragraphs without a CSS class show up as "Normal paragraph"
  in the styles menu. Fixes http://dev.plone.org/plone/ticket/10532.
  [davisagli]

- Avoid unneeded imports.
  [hannosch]

- Made toolbar background transparent and made padding symmetrical.
  [limi]

1.1rc12 (2010-06-03)
--------------------

- Remove tabindex deprecated html attribute
  [edegoute]

- Fixed some i18n bugs (#10339, #9637).
  [dmunicio]

- Added Spanish translations for plone.tinymce domain
  [dmunicio]

- Updated to upstream translations. Added Georgian (ka) language.
  [vincentfretin]

1.1rc11 (2010-05-01)
--------------------

- Fix regression in handling of resolveuid links that don't include an anchor.
  [davisagli]

- Include a copy of resolveuid.py so that links by UID can be resolved even
  when kupu is not installed and the transform is not applied (such as when
  inserting images in the first place).
  [davisagli]

- Prefer xml.etree over elementtree.
  [hannosch]

- Fixed test failure and avoid bare try/except statements related to portal
  factory and the save button.
  [hannosch]

1.1rc10 (2010-03-09)
--------------------

- Upgrade to TinyMCE 3.2.7.
  [robgietema]

- Fixed fullscreen mode, ticket #10080.
  [robgietema]

- Fixed search with Virtual Hosting, ticket #10308.
  [robgietema]

- Specified empty value and title attributes in searchreplace.htm.pt
  and template.htm.pt to make i18ndude happy.
  [vincentfretin]

- Added and updated languages from upstream.
  [vincentfretin]

- Updated pop-ups to match the Plone 4 style, and increased the default window
  sizes a bit to avoid scrollbars.
  [limi]

- Added content id so dialogs get the right style.
  [robgietema]

- Don't fail if kupu_library_tool is not available
  [naro]

- #155 transform can now handle anchors in resolveuid links
  (added test in transforms.txt)
  [fRiSi]

1.1rc9 (2010-02-18)
-------------------

- Removed id="region-content" from the templates, since it no longer has any function.
  See http://dev.plone.org/plone/ticket/10231 for more information.
  [limi]

- Removed the font-size styling in content.css, Plone is responsible for these styles anyway.
  [limi]

- Added ploneinlinestyles plugin so inline styles get filtered based on html
  filtering settings.
  [robgietema]

- Changed list style to use classes (merge from xhtml-strict branche).
  [robgietema]

- Added scope option to table cell dialog (merge from xhtml-strict branche).
  [robgietema]

- Correct link to parent of current item.
  [arrowman]

- Use &rarr; as breadcrubm separator instead of '-', like Plone does.
  [arrowman]

- Added missing Finnish translations.
  [pingviini]

1.1rc8 (2009-12-21)
-------------------

- Fix when editing contextuals portlets.
  #117 http://plone.org/products/tinymce/issues/117
  [sylvainb]

- Added a widget option: toolbar_width.
  [oliverroch]

- Fixed: "Normal paragraph" default style didn't reset css class.
  [oliverroch]

- Show dimensions of original image in imageupload-popup.
  [tom_gross]

1.1rc7 (2009-11-18)
-------------------

- Link and image drawers now look at INavigationRoot and not at IPloneSiteRoot.
  [robgietema, hannosch]

- Added support for LinguaPlone's translation aware reference handling to the
  new lookup_uid method.
  [hannosch]

- Removed translate calls inside TinyMCE utility. You don't have access to the
  request inside a utility and therefor cannot translate anything.
  [hannosch]

- Factored out resolveuid handling in the TinyMCEOutput parser to a
  lookup_uid method.
  [hannosch]

- Review french translation from Nicolas LAURANCE
  [toutpt]

- Add support for i18nized styles
  [toutpt]

1.1rc6 (2009-10-12)
-------------------

- Moved skin layer up.
  [robgietema]

- Added an `icon_expr` to the control panel entry.
  [hannosch]

- Fixed bug when editing the same field twice using inline editing.
  [robgietema]

- Fixed bug where lists couldn't get custom classes (thanks Artur Konstanczak).
  [robgietema]

- Fixed translations for insert image/link button tooltips.
  [robgietema]

- Use a span instead of p tag for the discreet style to allow the remove
  styles command/button to work properly.
  [esteele]

- Corrected spelling of 'contributors' and renamed doc accordingly.
  [rockdj]

- Fixed inserting images and links.
  [optilude]

1.1rc5 (2009-09-30)
-------------------

- Improved test coverage.
  [robgietema]

- Moved inline style from templates to css files.
  [maartenkling]

- Removed inline style  style="display:none;" from body tag from templates.
  [maartenkling]

- Fixed bug where custom image classes wouldn't stick after editing an image.
  [robgietema]

- Removed z3c.json dependancy, changed to simplejson or built-in json.
  [kingel]

- Register import/export handlers as zcml statements.
  [kingel]

- Set javascript files as cachable and mergable.
  [robgietema]

- Removed getInfoFromBrain method in JSONFolderListing and JSONSearch.
  [robgietema]

- Added support for comment nodes in Generic Setup.
  [robgietema]

- Changed hard coded css imports in dialogs to the generated plone.css.
  [robgietema]

- Changed condition for Javascript includes.
  [robgietema]

- Fix for static image sizes.
  [robgietema]

- Added richTextWidget to list of valid classes for a rich text widget to
  support non-AT widgets.
  [robgietema]

- Renamed configlet and moved to Plone section.
  [robgietema]

- Removed browsercheck from isTinyMCEEnabled method.
  [robgietema]

- Removed default values from interfaces/utility.py since they are already set
  by the Generic Setup profile.
  [robgietema]

- Removed .mo files from version control.
  [robgietema]

- Added translations for simpleterms in controlpanel.
  [robgietema]

- Get anchors from primary field and not from the 'text' field.
  [robgietema]

- Fixed misspelled breadcrumbs.
  [robgietema]

- Fix TinyMCEOutput parser to correctly recognise CDATA sections. TinyMCE puts
  the contents of script tags in CDATA sections.
  [optilude]

- Add french translation.
  [toutpt]

- Use AT mutator when setting title and description when uploading a file,
  otherwise this doesn't work on blobs.
  [optilude]

1.1rc4 (2009-09-04)
-------------------

- Added hiding upload button when you don't have permission to upload.
  [robgietema]

- Fixed jumping when up one level is hidden.
  [robgietema]

- Add allow_upload marker to results.
  [optilude]

- Support iframe attributes.
  [optilude]

- Fixed parent url when object is not folderish.
  [robgietema]

- Added tests for adapters.
  [robgietema]

- Fixed template error for Plone 4.
  [robgietema]

- Fix evil use of test setup code in the views.
  [optilude]

- Load plugins correctly.
  [optilude]

- Fixing TinyMCEConfig call to use the same id as the id attribute gets set to
  (this makes it work in IE again and not error in FF).
  [evilbungle]

- Several fixes to the Generic Setup import.
  [MatthewWilkes]

- Fixed selecting link after uploading a file when using link by uid.
  [robgietema]

- Fixed initialisation error in Safari.
  [robgietema]

- Fixed error when inserting images in a new document and using uids.
  [robgietema]

- Fixed error in definition list.
  [robgietema]

- In the image and link drawers get the id of an item if the title is not
  specified.
  [robgietema]

- Fixed width and height attributes getting undefined values.
  [robgietema]

- UID links are now generated absolute and not relative so the body can be
  displayed in other contexts also.
  [maerteijn]

- Upgrade to TinyMCE 3.2.6
  [robgietema]

- Fixed issue with preload image in IE returning the cached image.
  [robgietema]

- Added default_editor fix for textFormatSelector also.
  [robgietema]

- Added Finnish translations.
  [pingviini]

- Make default_editor site property getter fail gracefully.
  [MatthewWilkes]

- Fix bug that prevented user-specified plugins getting added.
  [MatthewWilkes]

- Remove ploneimage and plonelink from the hardcoded plugins and add them to the
  control panel box. This allows people to select the default image and link
  dialogues. Readded dialogues removed in rc3.
  [MatthewWilkes]

1.1rc3 (2009-08-18)
-------------------

- Upgrade to TinyMCE 3.2.5.
  [robgietema]

- Added support for definition lists.
  [robgietema]

- Added autoresize plugin and removed autoresize bottom margin from control
  panel.
  [robgietema]

- Added rooted feature, which roots the user to the current object.
  [robgietema]

- Added plone.tinymce as i18n domain so control panel screens etc can be
  translated.
  [robgietema]

- Added Dutch translation for plone.tinymce domain.
  [robgietema, ralphjacobs]

- Renamed advlink to plonelink, advimage to ploneimage and style to plonestyle.
  [robgietema]

- Rearranged image, link and table buttons.
  [robgietema]

- Added support for 'site default' editor for Plone 4.
  [robgietema]

- Get html filter settings from safe_html transform when available (Plone 4).
  [robgietema]

- Fixed compatibility with Plone 4.
  [robgietema]

- Added uninstall profile.
  [jaroel]

- Created upgrade steps from 1.0. to 1.1.
  [jaroel, robgietema]

- Removed json lib in favor of z3c.json package.
  [robgietema]

- Removed jscripts/tiny_mce folder levels in the skin folder.
  [robgietema]

- Removed fullpage and example plugin.
  [robgietema]

- Moved all html templates from dtml to pt.
  [robgietema]

- Use portal_type instead of meta_type for identification of resource types.
  [robgietema]

- Added customtoolbarbutton property to the control panel so custom.
  toolbarbuttons can be added.
  [robgietema]

- Added ploneCustom.css to dialogs.
  [robgietema]

- The default image description (used for alt) is the image title.
  [robgietema]

- When an image is uploaded en no title is specified the title will become the
  id.
  [robgietema]

- Fixed issue with linkbyuid not working when images were not captioned.
  [robgietema]

- Fixed save button in fullscreen mode.
  [robgietema]

- Fixed error when styles and/or table styles were empty.
  [robgietema]

- Added internal-link class to internal links.
  [robgietema]

- A lot of minor bugfixes.
  [robgietema]

- Modified the image drawer to retrieve the actual image scales for the image
  object selected.
  The ALT text box is pre-populated with the image description or if that's
  empty then the image title.
  The upload / image details panels now toggle depending on the action you're
  performing.
  [Ben Mason (sparcd), Per Thulin (pthulin), James Guest, Owen]

- Fixed AttributeError: 'NoneType' object has no attribute 'split'
  when reinstalling TinyMCE from 1.1rc1 to 1.1rc2: adding the
  customplugins attribute fails as this attribute is not there yet
  (isn't it ironic...).  I cannot reproduce the error in a fresh site,
  but I have seen it in the wild.
  [maurits]

1.1rc2 (2009-06-08)
-------------------

- Added entity encoding configuration option.
  [robgietema]

- Update to TinyMCE 3.2.4.1.
  [robgietema]

- Removed KSS dependency for initialization (KSS is still needed for inline
  editing).
  [robgietema]

1.1rc1 (2009-03-14)
-------------------

- Upgrade to TinyMCE 3.2.2.
  [robgietema]

- Updated language packs (7 new languages added).
  [robgietema]

- Added search function to image and link drawers including live search.
  [robgietema]

- When a new link is inserted and the selected text contains an URL it is
  automatically prepopulated.
  [robgietema]

- When a link is pasted the prefix is automatically stripped and put in the
  select box.
  [robgietema]

- Headings and subheadings are now automatically put in the anchor tab of the
  link selection dialog as an available option.
  [robgietema]

- Options to the control panel added to enable/disable the contextmenu.
  [robgietema]

- Added visual feedback to save as draft button.
  [robgietema]

- Added dialog to edit lang and dir attributes per tag.
  [robgietema]

- Option added to include custom plugins.
  [robgietema]

- Fixed issue when newlines were stripped in the transform.
  [maerteijn]

- Fixed link dialog size in Firefox.
  [robgietema]

- Fixed blockquote insert tag.
  [robgietema]

- Fixed link and imagedrawer when current item is folderish.
  [robgietema]

- Fixed issue with language configuration.
  [robgietema]


1.0 (2009-01-18)
----------------

- Fixed incorrect table classes.
  [robgietema]

- Fixed inline editing bug.
  [robgietema]

- Fixed ordered list.
  [robgietema]

- Fixed xhtml compliance.
  [robgietema]

- Fixed external link dialog.
  [robgietema]

1.0rc2 (2008-12-09)
-------------------

- Upgrade to TinyMCE 3.2.1.1.
  [robgietema]

- Added preview button for external links.
  [robgietema]

- Added auto select on upload when adding images and files.
  [robgietema]

- Fix for web-intelligent RichText fields.
  [robgietema]

- Fix for selecting links with double quote in the objectname.
  [robgietema]

- Fixed insert media dialog.
  [robgietema]

- Fixed IE7 scrolling bug, Fixed HTML Filtering settings bug.
  [robgietema]

1.0rc1 (2008-11-18)
-------------------

- Upgrade to TinyMCE 3.2.1 (and new logo).
  [robgietema]

- Merged blockformats and styles into one styles menu.
  [robgietema]

- Added support for parastyles in widget definition.
  [robgietema]

- Added link usings uids for images and internal links.
  [robgietema, maerteijn]

- Added the captioned images option.
  [robgietema, maerteijn]

- Get HTML Filtering settings from the control panel.
  [robgietema]

- Added integration tests.
  [robgietema]

- Added export/import of settings through GenericSetup (tinymce.xml).
  [robgietema]

- Added i18n support + language packs.
  [robgietema]

- Fixed inline editing.
  [robgietema]

- Moved load/save events to kss.
  [robgietema]

- Fixed save button on the toolbar, now using an ajax method.
  [robgietema]

- Moved all configuration data to json structure in page template of the widget.
  [robgietema]

- Changed toolbar save user feedback from alert message to blinking field border
  (idea by Danny).
  [robgietema]

- Removed save button when creating a new object.
  [robgietema]

- Added bottom margin of the editor window when auto resize is enabled to the
  control panel.
  [robgietema]

- Added condition to javascript files in portal registery.
  [robgietema]

- Fixed IE6 and 7 loading and dialog bugs.
  [robgietema]

- Fixed toolbar/statusbar backgroundcolor bug in IE6 and 7.
  [robgietema]

- Fixed width of file field in image and file upload dialog for Safari.
  [robgietema]

- Fixed inline style filtering.
  [robgietema]

- Fixed indenting/outdenting of lists.
  [robgietema]

0.96.3.1.1 (2008-10-23)
-----------------------

- Added external toolbar option.
  [robgietema]

- Autogrow option.
  [robgietema]

- Handling for allow and filter_buttons.
  [robgietema]

- Changed style of the editorfield so it matches the other widgets (gray
  borders, blue toolbar, orange border when selected etc).
  [robgietema]

- Added javascripts to portal registery.
  [robgietema]

- Fixed bug with multiple editors on one page (issue #7).
  [robgietema]

- CSS fixes for NuPlone.
  [robgietema]

- Fixed issue with plone formgen style (issue #8).
  [robgietema]

- Fixed tablecel bug (issue #6).
  [robgietema]

- Removed dom path from location bar.
  [robgietema]

- Removed unused skins of popups.
  [robgietema]

- Fixed position of modal dialog blocker and move dialog window (backport from
  TinyMCE 3.2).
  [robgietema]

- Fixed "jumping" issues in the link and image dialog when using Safari.
  [robgietema]

0.95.3.1.1 (2008-09-11)
-----------------------

- Eggification of TinyMCE.
  [robgietema, kingel]

- Upgrade to TinyMCE 3.1.1.
  [robgietema]

- Minor table fixes.
  [robgietema]

0.94.3.1.0.1 (2008-07-11)
-------------------------

- Upgrade to TinyMCE 3.1.0.1.
  [robgietema]

- Added support for NuPlone.
  [robgietema]

- Minor bugfixes.
  [robgietema]

0.93.3.0.8 (2008-05-17)
-----------------------

- Upgrade to TinyMCE 3.0.8.
  [robgietema]

- Upgrade to Plone 3.1.1.
  [robgietema]

- Added control panel.
  [robgietema]

0.92.2.0.6 (2006-06-02)
-----------------------

- Upgrade to TinyMCE 2.0.6.1.
  [turgmr2]

- Add separate language downloads.
  [turgmr2]

0.91.2.0.5
----------

- Bugfix for linux systems.
  [turgmr2]

0.90.2.0.5 (2006-03-31)
-----------------------

- Upgrade to TinyMCE 2.0.5.1.
  [turgmr2]

- Fix bug with relative links.
  [turgmr2]

0.90.2.0.2 (2006-01-24)
-----------------------

- Upgrade to TinyMCE 2.0.2.
  [turgmr2]

0.90.1.45 (2005-10-03)
----------------------

- Use javascript_head_slot instead of editing the header template.
  [turgmr2]

0.81.1.45 (2005-08-23)
----------------------

- Upgrade to TinyMCE 1.45 (final).
  [turgmr2]

- Optimize javascript.
  [turgmr2]

- Update the instructions.
  [turgmr2]

0.80.1.45rc1 (2005-06-07)
-------------------------

- Strip all languages except English.
  [turgmr2]

- Upgrade internally to 1.45rc1.
  [turgmr2]

0.80.1.44
---------

- Allow cohabitation with Kupu and Epoz.
  [turgmr2]

0.75.1.44
---------

- Write install documentation and notes.
  [turgmr2]

0.70.1.44
---------

- Get the rest of the features and enable plugins.
  [turgmr2]

0.50.1.44
---------

- Get installable product and some features.
  [turgmr2]

0.10.1.44
---------

- Get minimal functionality.
  [turgmr2]

.. _`#99`: https://github.com/collective/sc.social.like/pull/99
